/**
 * sigma_action_registry.js
 * 
 * Main registry that imports and registers all Sigma action handlers
 */
const logger = require('../../../utils/logger');
const { registerViewActions } = require('./sigma_view_actions');
const { registerConversionActions } = require('./sigma_conversion_actions');
const { registerSiemActions } = require('./sigma_siem_actions');
const { processRuleDetails, processRuleConversion } = require('./sigma_action_core');

const FILE_NAME = 'sigma_action_registry.js';

/**
 * Register all Sigma-related action handlers
 * 
 * @param {Object} app - The Slack app instance
 */
const registerActionHandlers = (app) => {
  logger.info(`${FILE_NAME}: Registering all sigma action handlers`);

  // Register view-related handlers (view YAML, view details, pagination)
  registerViewActions(app);
  
  // Register conversion-related handlers
  registerConversionActions(app);
  
  // Register SIEM-related handlers (send to SIEM, space selection)
  registerSiemActions(app);

  logger.info(`${FILE_NAME}: All sigma action handlers registered successfully`);
};

module.exports = {
  registerActionHandlers,
  processRuleDetails,
  processRuleConversion
};