/**
 * sigma_conversion_actions.js
 * 
 * Handlers for Sigma rule conversion actions
 */
const logger = require('../../../utils/logger');
const { handleError } = require('../../../utils/error_handler');
const { processRuleConversion } = require('./sigma_action_core');

const FILE_NAME = 'sigma_conversion_actions.js';

/**
 * Register conversion-related action handlers
 * 
 * @param {Object} app - The Slack app instance
 */
const registerConversionActions = (app) => {
  logger.info(`${FILE_NAME}: Registering conversion-related action handlers`);

  // Handle convert_rule_to_siem button clicks
  app.action('convert_rule_to_siem', async ({ body, ack, respond }) => {
    try {
      await ack();
      logger.debug(`${FILE_NAME}: convert_rule_to_siem action received: ${JSON.stringify(body.actions)}`);

      if (!body || !body.actions || !body.actions[0] || !body.actions[0].value) {
        logger.error(`${FILE_NAME}: Invalid action payload: missing rule ID`);
        await respond({
          text: 'Error: Could not determine which rule to convert',
          replace_original: false
        });
        return;
      }

      // Extract rule ID from button value
      const ruleId = body.actions[0].value.replace('convert_rule_to_siem_', '');
      logger.info(`${FILE_NAME}: convert_rule_to_siem button clicked for rule: ${ruleId}`);

      const config = {
        backend: 'lucene',
        target: 'ecs_windows',
        format: 'siem_rule_ndjson'
      };

      await processRuleConversion(ruleId, config, respond, false, 'in_channel');
    } catch (error) {
      await handleError(error, `${FILE_NAME}: convert_rule_to_siem action`, respond, {
        replaceOriginal: false
      });
    }
  });

  logger.info(`${FILE_NAME}: All conversion action handlers registered successfully`);
};

module.exports = {
  registerConversionActions
};