/**
 * command_patterns.js
 * 
 * Defines pattern matching rules for natural language commands
 * Each pattern includes a regex and mapping for parameter extraction
 */

/**
 * Command patterns array
 * Each pattern object contains:
 * - name: A descriptive name for the pattern
 * - regex: A regular expression to match the command
 * - action: The action to perform (e.g., details, search)
 * - module: The module to use (e.g., sigma, alerts)
 * - params: Array of capturing group indices to extract parameters
 */
const commandPatterns = [
    // Sigma details patterns
    {
        name: 'sigma-details',
        regex: /^details\s+sigma\s+(.+)$/i,
        action: 'details',
        module: 'sigma',
        params: [1] // rule ID is in capturing group 1
    },
    // Sigma search patterns
    {
        name: 'sigma-search',
        regex: /^(search|find)\s+(sigma\s+)?(rules|detections)?\s*(where|with)\s+(.+)$/i,
        action: 'complexSearch',
        module: 'sigma',
        params: [5] // complex query conditions in capturing group 5
    },

    // Sigma create patterns
    {
        name: 'sigma-create',
        regex: /^(create|convert)\s+sigma\s+rule\s+where\s+id=(.+)$/i,
        action: 'create',
        module: 'sigma',
        params: [2] // rule ID is in capturing group 2
    },
    
    // Sigma stats patterns
    {
        name: 'sigma-stats-first',
        regex: /^sigma\s+stats$/i,
        action: 'stats',
        module: 'sigma',
        params: []
    },
    {
        name: 'sigma-stats-second',
        regex: /^stats\s+sigma$/i,
        action: 'stats',
        module: 'sigma',
        params: []
    }
];

module.exports = commandPatterns;